﻿using System;
using UA;

namespace CSI_UA
{
    class Program
    {
        static void Main(string[] args)
        {
            TestUA testUA = new TestUA();
            testUA.Run();
        }
    }

    /// <summary>
    /// Simple test of UA data access
    /// </summary>
    internal class TestUA
    {
        API2Class uaApi2;
        DateTime fromDate, toDate;
        int loadStartDate, loadEndDate, marketNumber, monthYear, count;
        object IntResultArray = null;
        object FltResultArray = null;

        /// <summary>
        /// test constructor
        /// </summary>
        public TestUA()
        {
            uaApi2 = new API2Class();
            fromDate = DateTime.MinValue;
            toDate = DateTime.MaxValue;
            loadStartDate = fromDate.Equals(DateTime.MinValue) ? -1 : Convert.ToInt32(fromDate.ToString("yyyyMMdd"));
            loadEndDate = toDate.Equals(DateTime.MaxValue) ? -1 : Convert.ToInt32(toDate.ToString("yyyyMMdd"));
            marketNumber = 141; // ED
            monthYear = 201812; // 200903;  // Contract maturity
        }

        /// <summary>
        /// test run
        /// </summary>
        public void Run()
        {
            Console.WriteLine("Retrieving Contract {0} Maturity:{1}...", marketNumber, monthYear);
            uaApi2.RetrieveContract(marketNumber, monthYear, loadStartDate, loadEndDate);
            Console.WriteLine("CopyRetrievedDataToArray2 for Contract {0}...", marketNumber);
            count = uaApi2.CopyRetrievedDataToArray2(0, out IntResultArray, out FltResultArray);

            if (count < 0)
            {
                Console.WriteLine("No data found for contract {0}", marketNumber);
                return;
            }

            double[,] singleArray = FltResultArray as double[,];    // Use this when CopyRetrievedDataToArray2 has been used
            //single[,] singleArray = FltResultArray as single[,];  // Use this when RetrieveSnapShot has been used
            Int32[,] intArray = IntResultArray as Int32[,];

            Console.WriteLine("Printing results for Contract {0}...", marketNumber);
            for (int j = 0; j < count; j++)
            {
                Console.WriteLine("{0} O:{1} H:{2} L:{3} C:{4} V:{5} OpenInt:{6} TotalVol:{7} TotalOpenInt:{8} CloseBid:{9} CloseAsk:{10} Dow:{11}",
                    DateTime.ParseExact(intArray[0, j].ToString(), "yyyyMMdd", System.Globalization.CultureInfo.InvariantCulture).ToShortDateString(),
                    singleArray[1, j],  // open
                    singleArray[2, j],  // high
                    singleArray[3, j],  // low
                    singleArray[4, j],  // close
                    intArray[3, j],     // Volume of trading for this contract);
                    intArray[4, j],     // open interest for this contract.
                    intArray[5, j],     // Total volume of trading for the commodity.
                    intArray[6, j],     // Total Open Interest in this commodity.
                    singleArray[5, j],  // The closing bid 
                    singleArray[6, j],  // The closing ask 
                    singleArray[7, j]); // Dow (?)
            }

        }
    }
}
